==> adx-center-api-0.0.81-20230117.063201-1-sources.jar: cn/com/duiba/tuia/adx/center/api/remoteservice/RemotePopularGroupService.java <==
package cn.com.duiba.tuia.adx.center.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.adx.center.api.common.PageDto;
import cn.com.duiba.tuia.adx.center.api.dto.PopularGroupDto;
import cn.com.duiba.tuia.adx.center.api.dto.UpdatePreLoadAdvertDto;
import cn.com.duiba.tuia.adx.center.api.req.PopularGroupPageReq;

import java.util.List;

/**
 * 推广组服务
 *
 * @author weny.cai
 * @date 2018/11/29 14:55
 **/
@AdvancedFeignClient
public interface RemotePopularGroupService {

    boolean insert(PopularGroupDto dto) throws BizException;

    List<PopularGroupDto> selectByMediaId(Long mediaId);

    List<PopularGroupDto> selectByMediaId(List<Long> mediaIds);

    boolean update(PopularGroupDto dto) throws BizException;

    PageDto<PopularGroupDto> pageQuery(PopularGroupPageReq req);

    List<PopularGroupDto> getAll();

    boolean changeSwitchStateById(Long id,Integer switchState);

    /**
     * 根据id查询
     * @param id
     * @return
     */
    PopularGroupDto selectById(Long id);

    /**
     * 删除
     * @param id
     */
    void deleteById(Long id) throws BizException;

    List<Integer> selectAdxTypeByParam(PopularGroupPageReq req);

    List<PopularGroupDto> selectPageByAdxType(Long id, String groupName, List<Integer> adxTypes);

    List<Long> selectByAdxTypes(List<Integer> adxTypes);

    /**
     * 分页查询adxType列表
     */
    PageDto<Integer> pageQueryAdxType(PopularGroupPageReq req);

}

==> adx-center-api-0.1.46-sources.jar: cn/com/duiba/tuia/adx/center/api/remoteservice/RemotePopularGroupService.java <==
package cn.com.duiba.tuia.adx.center.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.adx.center.api.common.PageDto;
import cn.com.duiba.tuia.adx.center.api.dto.PopularGroupDto;
import cn.com.duiba.tuia.adx.center.api.dto.UpdatePreLoadAdvertDto;
import cn.com.duiba.tuia.adx.center.api.req.PopularGroupPageReq;

import java.util.List;

/**
 * 推广组服务
 *
 * @author weny.cai
 * @date 2018/11/29 14:55
 **/
@AdvancedFeignClient
public interface RemotePopularGroupService {

    boolean insert(PopularGroupDto dto) throws BizException;

    List<PopularGroupDto> selectByMediaId(Long mediaId);

    boolean update(PopularGroupDto dto) throws BizException;

    PageDto<PopularGroupDto> pageQuery(PopularGroupPageReq req);

    List<PopularGroupDto> getAll();

    boolean changeSwitchStateById(Long id,Integer switchState);

    /**
     * 根据id查询
     * @param id
     * @return
     */
    PopularGroupDto selectById(Long id);

    /**
     * 删除
     * @param id
     */
    void deleteById(Long id) throws BizException;

    List<Integer> selectAdxTypeByParam(PopularGroupPageReq req);

    List<PopularGroupDto> selectPageByAdxType(Long id, String groupName, List<Integer> adxTypes);

    List<Long> selectByAdxTypes(List<Integer> adxTypes);

    /**
     * 分页查询adxType列表
     */
    PageDto<Integer> pageQueryAdxType(PopularGroupPageReq req);

    /**
     * 根据媒体id列表查询推广组id列表
     */
    List<PopularGroupDto> selectByMediaIdList(List<Long> mediaIdList);

}
